#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : setup.py.py
# @Author: hanyan_news
# @Desc  :


from distutils.core import setup
from setuptools import find_packages

with open("README.rst", "r") as f:
  long_description = f.read()


setup(name='package-tea-four',  # 包名
      version='1.0.0',  # 版本号
      description='a small package just example',
      long_description=long_description,
      author='hanyan_news',
      author_email='hanyan0572@gmail.com',
      url='https://github.com/hanyan007/package-tea-four.git',
      install_requires=["package-tea-three==1.0.0"],
      project_urls={  # Optional
        "Source": 'https://github.com/hanyan007/package-tea-four.git',
      },
      license='BSD License',
      packages=find_packages(),
      platforms=["all"],
      classifiers=[
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Natural Language :: Chinese (Simplified)',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Topic :: Software Development :: Libraries'
      ],
      )



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File  : main.py
# @Author: hanyan_news
# @Desc  :

import itertools


case_lists = ['username', 'password']
value_lists = ['correct', 'incorrect', 'specific symbol', 'maximum length']


def gen_case(item=case_lists, value=value_lists):
    '''输出笛卡尔用例集合'''
    for i in itertools.product(item, value):
        print('输入'.join(i))

def test_print():
	print("hello world!")

if __name__ == '__main__':
    # test_print()
    gen_case(）